#set working directory
setwd("~/Dropbox/BlackmailData")
library(tidyverse)
library(ggplot2)
library(ggpubr)

#We read in the files 
lustration<-read_csv("~/Dropbox/BlackmailData/LustrationPanel_CI.csv")
truthcom<-read_csv("~/Dropbox/BlackmailData/TruthCommission_CI.csv")
lpurge<-read_csv("~/Dropbox/BlackmailData/LeadershipPurge_CI.csv")
tpurge<-read_csv("~/Dropbox/BlackmailData/ThoroughPurge_CI.csv")

#I create the new columns specifying which type of Tj events by using mutate function:
lustration<-lustration%>%mutate(TJtype="Transparency")
truthcom<-truthcom%>%mutate(TJtype="Transparency")
lpurge<-lpurge%>%mutate(TJtype="Purges")
tpurge<-tpurge%>%mutate(TJtype="Purges")


#To merge the files together, you can do the following:
merged<-rbind(lustration, truthcom,lpurge,tpurge)


#Disaggregated
#Transition Year
disagg_year<-ggplot(data=merged)+
  geom_smooth(mapping=aes(x=year,y=pmntrans,color=TJtype),show.legend = TRUE)+ labs(x="Transition Year", y="Progressive TJ Events net of regressive events", color="Type of TJ",
                                                                                     title="Purges and Transparency over time")

disagg_year<-disagg_year+scale_color_manual(values=c("Transparency"="#7CAE00", "Purges"="#00BFC4"), 
                                              labels =c("Transparency", "Purges"))

ggsave("SinceTransitionYear.png", width=10.5, height=3.75)

#Year After
disagg_yaftr<-ggplot(data=merged)+
  geom_smooth(mapping=aes(x=yaftr,y=pmntrans,color=TJtype),show.legend = TRUE)+
  labs(x="Years After Transition", y="Progressive TJ Events net of regressive events", color="Type of TJ",
       title="Purges and Transparency over time as a function of years since trnasition")


disagg_yaftr<-disagg_yaftr+scale_color_manual(values=c("Transparency"="#7CAE00", "Purges"="#00BFC4"), 
                                              labels =c("Transparency", "Purges"))

ggsave("YearsSinceTransition.png", width=10.5, height=3.75)

#Combining into Single Plot
#combined<-ggarrange(pooled_yaftr, disagg_yaftr,pooled_tyear, disagg_tyear,
#         ncol = 2, nrow= 2)
#ggsave("combined_LUS_TRUTH.png", width=10.5, height=7)

#Combining into one plot the disaggregated graphs [could not use this because of problems with ggpubr]
combined<-ggarrange(disagg_yaftr, disagg_tyear,
                    ncol = 2, nrow= 1)


ggsave("combined_DISAGGREGATED.png", width=10.5, height=3.75)


